@@ -5,9 +5,9 @@
 @mail: ylxx@live.com
 Created on Sun Jan 12 17:06:39 2020
 """
-
+import boxx
 from boxx import *
-from boxx import os, setTimeout, mapmt, timegap, sleep
+from boxx import os, setTimeout, mapmt, timegap, sleep, pathjoin
 
 import random
 import glob
@@ -34,6 +34,7 @@ class HdriManager:
         resolution="4k",
         category="all",
         download=False,
+        debug=False,
     ):
         """
         Download and manage hdri file from https://hdrihaven.com/hdris/
@@ -60,17 +61,21 @@ class HdriManager:
             The default is False.
         """
         self.resolution = resolution
-        self.category = category
+        self.category = category.lower().replace("/", "-")
         self.hdri_dir = hdri_dir
         os.makedirs(hdri_dir, exist_ok=True)
         self.downloading = download
+        self.debug = debug
         if self.downloading:
             print('Starting download ".hdr" file from "hdrihaven.com" in side threads')
-            setTimeout(self.prepare)
+            if debug:
+                self.prepare()
+            else:
+                setTimeout(self.prepare)
         self.set_hdr_paths()
 
     def set_hdr_paths(self):
-        self.hdr_paths = sorted(
+        self.all_paths = sorted(
             sum(
                 [
                     glob.glob(os.path.join(self.hdri_dir, f"*.{ext}"))
@@ -79,6 +84,32 @@ class HdriManager:
                 [],
             )
         )
+        if self.category == "all":
+            self.hdr_paths = sorted(self.all_paths)
+            return
+
+        listt = []
+        for path in self.all_paths:
+            fname = boxx.filename(path)
+            name = fname.split(".")[0]
+            listt.append(
+                dict(
+                    name=name,
+                    res=name.split("_")[-1],
+                    cats=fname.split(".")[1].split("="),
+                    tags=fname.split(".")[2].split("="),
+                    path=path,
+                )
+            )
+        self.df = boxx.pd.DataFrame(listt)
+        if self.category == "all":
+            hdr_paths = self.df.path
+        else:
+            hdr_paths = self.df[
+                self.df.cats.apply(lambda cats: self.category in cats)
+            ].path
+
+        self.hdr_paths = sorted(hdr_paths)
 
     def __len__(self):
         if self.downloading:
@@ -110,46 +141,75 @@ class HdriManager:
         url = f"https://hdrihaven.com/hdris/category/?c={category}"
         page = rq.get(url, timeout=5)
         html = BeautifulSoup(page.text, features="html.parser")
-        # '/hdri/?c=indoor&h=colorful_studio'
         hrefs = [a["href"] for a in html.find(id="item-grid").find_all("a")]
 
         names = [url2dict(href)["h"][0] for href in hrefs]
 
         #  'https://hdrihaven.com/files/hdris/tv_studio_4k.hdr'
-        download_urls = [
-            f"https://hdrihaven.com/files/hdris/{name}_{resolution}"  # + .hdr or .exr
-            for name in names
-        ]
+        def download(name):
+            try:
+                if self.debug:
+                    print(name)
+                prefix = f"{name}_{resolution}"
+                paths = boxx.glob(os.path.join(hdri_dir, prefix + "*"))
+                if len(paths):
+                    return paths[0]
+                url = f"https://hdrihaven.com/hdri/?h={name}"
+                html = BeautifulSoup(
+                    rq.get(url, timeout=5).text, features="html.parser",
+                )
+                href = [
+                    a["href"]
+                    for a in html.find_all("a")
+                    if f"_{resolution}." in a.get("href")
+                ][0]
+                cats = [
+                    a.text
+                    for a in html.find(text="Categories:").parent.parent.find_all("a")
+                ]
+                tags = [
+                    a.text for a in html.find(text="Tags:").parent.parent.find_all("a")
+                ]
+                name = f"{prefix}.{'='.join(cats)}.{'='.join(tags)}.{href[-3:]}"
 
-        def download(url):
-            fname = os.path.basename(url)
-            file_path = os.path.join(hdri_dir, fname)
-            for ext in self.exts:
-                path = f"{file_path}.{ext}"
-                if os.path.isfile(path):
-                    return path
-            for ext in self.exts:
-                path = f"{file_path}.{ext}"
-                downlaod_url = f"{url}.{ext}"
-                r = rq.get(downlaod_url, timeout=5)
-                if r.status_code != 200:
-                    continue
+                path = pathjoin(hdri_dir, name)
+                r = rq.get(href, timeout=5)
+                assert r.status_code == 200
                 os.makedirs(hdri_dir, exist_ok=True)
                 with open(path, "wb") as f:
                     f.write(r.content)
                 return path
-            raise Exception(f"Con't download {file_path}")
+            except Exception as e:
+                if self.debug:
+                    boxx.pred - name
+                    boxx.g()
+                raise e
 
-        _urls = download_urls[:]
-        random.shuffle(_urls)
-        mapmt(download, _urls, pool=2)
+        _names = names[:]
+        random.shuffle(_names)
+        if self.debug:
+            list(map(download, _names,))
+        else:
+            mapmt(download, _names, pool=1)
         self.set_hdr_paths()
         self.downloading = False
         print("Download hdri threads has finished!")
 
+    @classmethod
+    def test(cls):
+        hdri_dir = "/tmp/hdri"
+        hm = HdriManager(
+            hdri_dir=hdri_dir, category="indoor", download=False, debug=True
+        )
+        for i in range(10):
+            hdri = hm.sample()
+            print(hdri)
+            assert hm.category in hdri
+        boxx.g()
+
 
 if __name__ == "__main__":
     hdri_dir = "/tmp/hdri"
-    hdri_dr = HdriManager(hdri_dir=hdri_dir, download=True)
-    hdri = hdri_dr.sample()
+    hm = HdriManager(hdri_dir=hdri_dir, download=True, debug=True)
+    hdri = hm.sample()
     print(hdri)
